==> bcozy-1.6.0-sources.jar: org/openbase/bco/bcozy/view/LocationContextInfo.java <==
/**
 * ==================================================================
 *
 * This file is part of org.openbase.bco.bcozy.
 *
 * org.openbase.bco.bcozy is free software: you can redistribute it and modify
 * it under the terms of the GNU General Public License (Version 3)
 * as published by the Free Software Foundation.
 *
 * org.openbase.bco.bcozy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with org.openbase.bco.bcozy. If not, see <http://www.gnu.org/licenses/>.
 * ==================================================================
 */
package org.openbase.bco.bcozy.view;

import javafx.scene.control.Label;
import javafx.scene.layout.AnchorPane;

/**
 * Created by hoestreich on 11/18/15.
 */
public class LocationContextInfo extends AnchorPane {

    private final Label locationInfo;

    /**
     * Constructor for the RoomContextInfo UI Element.
     */
    public LocationContextInfo() {

        locationInfo = new Label("No location selected.");

        this.getChildren().add(locationInfo);

        this.setLeftAnchor(locationInfo, Constants.INSETS);
        this.setRightAnchor(locationInfo, Constants.INSETS);
        this.setTopAnchor(locationInfo, Constants.INSETS);
        this.setBottomAnchor(locationInfo, Constants.INSETS);
    }

}

==> bcozy-1.6.2-sources.jar: org/openbase/bco/bcozy/view/LocationContextInfo.java <==
/**
 * ==================================================================
 *
 * This file is part of org.openbase.bco.bcozy.
 *
 * org.openbase.bco.bcozy is free software: you can redistribute it and modify
 * it under the terms of the GNU General Public License (Version 3)
 * as published by the Free Software Foundation.
 *
 * org.openbase.bco.bcozy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with org.openbase.bco.bcozy. If not, see <http://www.gnu.org/licenses/>.
 * ==================================================================
 */
package org.openbase.bco.bcozy.view;

import javafx.scene.control.Label;
import javafx.scene.layout.AnchorPane;

/**
 * Created by hoestreich on 11/18/15.
 */
@Deprecated
public class LocationContextInfo extends AnchorPane {

//    private final Label locationInfo;

    /**
     * Constructor for the RoomContextInfo UI Element.
     */
    public LocationContextInfo() {

//        locationInfo = new Label("No location selected.");
//
//        this.getChildren().add(locationInfo);
//
//        this.setLeftAnchor(locationInfo, Constants.INSETS);
//        this.setRightAnchor(locationInfo, Constants.INSETS);
//        this.setTopAnchor(locationInfo, Constants.INSETS);
//        this.setBottomAnchor(locationInfo, Constants.INSETS);
    }

}
